@@ -311,6 +311,8 @@ renv_dependencies_callback <- function(path) {
     "_bookdown.yml" = function(path) renv_dependencies_discover_bookdown(path),
     "_pkgdown.yml"  = function(path) renv_dependencies_discover_pkgdown(path),
     "_quarto.yml"   = function(path) renv_dependencies_discover_quarto(path),
+    "_server.yml"   = function(path) renv_dependencies_discover_plumber_server(path),
+    "_server.yaml"  = function(path) renv_dependencies_discover_plumber_server(path),
     "renv.lock"     = function(path) renv_dependencies_discover_renv_lock(path),
     "rsconnect"     = function(path) renv_dependencies_discover_rsconnect(path)
   )
@@ -595,7 +597,9 @@ renv_dependencies_discover_description <- function(path,
   names(data) <- fields
 
   # if this is a bioconductor package, add their implicit dependencies
-  if ("biocViews" %in% names(dcf)) {
+  # guard against packages which have an empty biocViews field
+  # https://github.com/rstudio/renv/issues/2149
+  if (nzchar(dcf[["biocViews"]] %||% "")) {
     data[[length(data) + 1L]] <- renv_dependencies_list(
       source = path,
       packages = c(renv_bioconductor_manager(), "BiocVersion")
@@ -701,6 +705,25 @@ renv_dependencies_discover_quarto <- function(path) {
   renv_dependencies_list_empty()
 }
 
+renv_dependencies_discover_plumber_server <- function(path) {
+  # require yaml package for parsing YAML
+  if (!renv_dependencies_require("yaml", basename(path)))
+    return(renv_dependencies_list_empty())
+
+  # read and parse yaml file
+  contents <- catch(yaml::read_yaml(path))
+  if (inherits(contents, "error"))
+    return(renv_dependencies_error(path, error = contents))
+
+  # check if engine field exists and has a value
+  engine <- contents$engine
+  if (!pstring(engine) || !nzchar(engine))
+    return(renv_dependencies_list_empty())
+
+  # return the engine as a dependency
+  renv_dependencies_list(path, engine)
+}
+
 renv_dependencies_discover_rsconnect <- function(path) {
   renv_dependencies_list(path, "rsconnect")
 }
@@ -857,9 +880,13 @@ renv_dependencies_discover_chunks_ignore <- function(chunk) {
     return(TRUE)
 
   # skip chunks whose labels end in '-display'
-  label <- chunk$params[["label"]] %||% ""
-  if (grepl("-display$", label))
+  label <- chunk$params[["label"]]
+  if (is.character(label) &&
+      length(label) == 1L &&
+      grepl("-display$", label))
+  {
     return(TRUE)
+  }
 
   # ok, don't ignore this chunk
   FALSE
@@ -1090,10 +1117,11 @@ renv_dependencies_discover_r <- function(path  = NULL,
     renv_dependencies_discover_r_require_namespace,
     renv_dependencies_discover_r_colon,
     renv_dependencies_discover_r_citation,
+    renv_dependencies_discover_r_data,
     renv_dependencies_discover_r_pacman,
     renv_dependencies_discover_r_modules,
     renv_dependencies_discover_r_import,
-    renv_dependencies_discover_r_box,
+    renv_dependencies_discover_r_use,
     renv_dependencies_discover_r_targets,
     renv_dependencies_discover_r_glue,
     renv_dependencies_discover_r_ggplot2,
@@ -1276,6 +1304,25 @@ renv_dependencies_discover_r_citation <- function(node, envir) {
 
 }
 
+renv_dependencies_discover_r_data <- function(node, envir) {
+
+  node <- renv_call_expect(node, "utils", "data")
+  if (is.null(node))
+    return(FALSE)
+
+  matched <- catch(match.call(utils::data, node))
+  if (inherits(matched, "error"))
+    return(FALSE)
+
+  package <- matched[["package"]]
+  if (!is.character(package) || length(package) != 1L)
+    return(FALSE)
+
+  envir[[package]] <- TRUE
+  TRUE
+
+}
+
 renv_dependencies_discover_r_pacman <- function(node, envir) {
 
   node <- renv_call_expect(node, "pacman", "p_load")
@@ -1418,20 +1465,65 @@ renv_dependencies_discover_r_import <- function(node, envir) {
 
 }
 
-renv_dependencies_discover_r_box <- function(node, envir) {
+renv_dependencies_discover_r_use <- function(node, envir) {
 
-  node <- renv_call_expect(node, "box", "use")
-  if (is.null(node))
+  # There are multiple possible packages providing a function called 'use'.
+  # renv will currently assume that any invocation of 'use' without a
+  # package prefix is one that belongs to 'base'.
+  if (is.call(node) && identical(node[[1L]], as.symbol("use")))
+    return(renv_dependencies_discover_r_use_base(node, envir))
+
+  # `base::use()`
+  m <- renv_call_expect(node, "base", "use")
+  if (length(m))
+    return(renv_dependencies_discover_r_use_base(m, envir))
+
+  # `renv::use()`
+  m <- renv_call_expect(node, "renv", "use")
+  if (length(m)) {
+    pkgs <- setdiff(names(m), names(formals(renv::use)))
+    for (pkg in pkgs)
+      if (nzchar(pkg))
+        envir[[pkg]] <- TRUE
+    return(TRUE)
+  }
+
+  # `box::use()`
+  m <- renv_call_expect(node, "box", "use")
+  if (length(m)) {
+    for (i in seq.int(2L, length.out = length(m) - 1L))
+      renv_dependencies_discover_r_use_box(m[[i]], envir)
+    return(TRUE)
+  }
+
+  # no implementation matched
+  FALSE
+
+}
+
+renv_dependencies_discover_r_use_base <- function(node, envir) {
+
+  # attempt to match the call
+  matched <- tryCatch(
+    match.call(function(package, include.only) {}, node),
+    error = identity
+  )
+
+  if (inherits(matched, "error"))
     return(FALSE)
 
-  for (i in seq.int(2L, length.out = length(node) - 1L))
-    renv_dependencies_discover_r_box_impl(node[[i]], envir)
+  # check for a character argument
+  package <- matched[["package"]]
+  if (!is.character(package))
+    return(FALSE)
 
+  # add to dependency set
+  envir[[package]] <- TRUE
   TRUE
 
 }
 
-renv_dependencies_discover_r_box_impl <- function(node, envir) {
+renv_dependencies_discover_r_use_box <- function(node, envir) {
 
   # if the call uses /, it's a path, not a package
   if (renv_call_matches(node, "/"))
