@@ -93,21 +93,21 @@ hydrate <- function(packages = NULL,
   # also consider remotes; if a package is listed within Remotes,
   # then choose to install that package instead of linking it
   filter <- function(specs, remotes) {
-    
+
     packages <- enum_chr(remotes, function(package, remote) {
-      
+
       # if we have a package name, use it
       if (is.character(package) && nzchar(package))
         return(package)
-      
+
       # otherwise, resolve the remote and use the package field
       remote <- resolve(remote)
       remote[["Package"]]
-      
+
     })
-    
+
     keep(specs, packages)
-    
+
   }
 
   remotes <- renv_project_remotes(project, filter = filter, resolve = TRUE)
@@ -258,11 +258,15 @@ renv_hydrate_libpaths <- function() {
 # to the (private) library 'library'
 renv_hydrate_link_package <- function(package, location, library) {
 
-  # construct path to cache
+  # compute package record
   record <- catch(renv_snapshot_description(location))
   if (inherits(record, "error"))
     return(FALSE)
 
+  # compute a hash now if we don't have one
+  record[["Hash"]] <- record[["Hash"]] %||% renv_hash_description(location)
+
+  # construct path to cache
   cache <- renv_cache_find(record)
   if (!nzchar(cache))
     return(FALSE)
@@ -273,6 +277,9 @@ renv_hydrate_link_package <- function(package, location, library) {
     renv_file_copy(location, cache)
   }
 
+  # invoke cache callbacks
+  renv_cache_callbacks(cache)
+
   # link package back from cache to library
   target <- file.path(library, package)
   ensure_parent_directory(target)
@@ -366,7 +373,7 @@ renv_hydrate_resolve_missing <- function(project, library, remotes, missing) {
       sprintf("[%s]: %s", package, short)
     })
 
-    caution_bullets(
+    bulletin(
       "The following package(s) were not installed successfully:",
       text,
       "You may need to manually download and install these packages."
@@ -416,7 +423,7 @@ renv_hydrate_report <- function(packages, na, linkable) {
   }
 
   if (length(na)) {
-    caution_bullets(
+    bulletin(
       "The following packages are used in this project, but not available locally:",
       csort(names(na)),
       "renv will attempt to download and install these packages."
