@@ -43,6 +43,11 @@ the$install_step_width <- 48L
 #'
 #' @inherit renv-params
 #'
+#' @param include Packages which should be installed. `include` can
+#'   occasionally be useful when you'd like to call `renv::install()` with
+#'   no arguments, but restrict package installation to only some subset
+#'   of dependencies in the project.
+#'
 #' @param exclude Packages which should not be installed. `exclude` is useful
 #'   when using `renv::install()` to install all dependencies in a project,
 #'   except for a specific set of packages.
@@ -52,6 +57,11 @@ the$install_step_width <- 48L
 #'   will be used. When `FALSE`, installation output will be emitted only if
 #'   a package fails to install.
 #'
+#' @param transactional Whether or not to use a 'transactional' package
+#'   installation. See **Transactional Restore** in [renv::restore()] for
+#'   more details. When `NULL` (the default), the value of the
+#'   `install.transactional` [`config`] option will be used.
+#'
 #' @param lock Boolean; update the `renv.lock` lockfile after the successful
 #'   installation of the requested packages?
 #'
@@ -87,16 +97,18 @@ the$install_step_width <- 48L
 #' }
 install <- function(packages = NULL,
                     ...,
-                    exclude      = NULL,
-                    library      = NULL,
-                    type         = NULL,
-                    rebuild      = FALSE,
-                    repos        = NULL,
-                    prompt       = interactive(),
-                    dependencies = NULL,
-                    verbose      = NULL,
-                    lock         = FALSE,
-                    project      = NULL)
+                    include       = NULL,
+                    exclude       = NULL,
+                    library       = NULL,
+                    type          = NULL,
+                    rebuild       = FALSE,
+                    repos         = NULL,
+                    prompt        = interactive(),
+                    dependencies  = NULL,
+                    verbose       = NULL,
+                    transactional = NULL,
+                    lock          = FALSE,
+                    project       = NULL)
 {
   renv_consent_check()
   renv_scope_error_handler()
@@ -122,6 +134,10 @@ install <- function(packages = NULL,
   verbose <- verbose %||% config$install.verbose()
   renv_scope_options(renv.config.install.verbose = verbose)
 
+  # handle 'transactional'
+  transactional <- transactional %||% config$install.transactional()
+  renv_scope_options(renv.config.install.transactional = transactional)
+
   # set up library paths
   libpaths <- renv_libpaths_resolve(library)
   renv_scope_libpaths(libpaths)
@@ -166,6 +182,10 @@ install <- function(packages = NULL,
   if (length(exclude))
     packages <- setdiff(packages, exclude)
 
+  # apply include parameter
+  if (length(include))
+    packages <- intersect(packages, include)
+
   if (empty(packages)) {
     writef("- There are no packages to install.")
     return(invisible(list()))
@@ -217,6 +237,14 @@ install <- function(packages = NULL,
     cancel_if(prompt && !proceed())
   }
 
+  # check for installed dependencies
+  if (config$sysreqs.check(default = renv_platform_linux())) {
+    paths <- map(records, `[[`, "Path")
+    sysreqs <- map(paths, renv_sysreqs_read)
+    renv_sysreqs_check(sysreqs, prompt = prompt)
+  }
+
+
   # install retrieved records
   before <- Sys.time()
   renv_install_impl(records)
@@ -432,8 +460,9 @@ renv_install_package <- function(record) {
 
   # link into cache
   if (renv_cache_config_enabled(project = project)) {
-    renv_cache_synchronize(record, linkable = linkable)
-    feedback <- paste0(feedback, " and cached")
+    cached <- renv_cache_synchronize(record, linkable = linkable)
+    if (cached)
+      feedback <- paste(feedback, "and cached")
   }
 
   verbose <- config$install.verbose()
@@ -462,14 +491,14 @@ renv_install_package_cache <- function(record, cache, linker) {
     return(TRUE)
 
   library <- renv_libpaths_active()
-  target <- file.path(library, record$Package)
+  target <- file.path(library, record[["Package"]])
 
   # back up the previous installation if needed
   callback <- renv_file_backup(target)
   defer(callback())
 
   # report successful link to user
-  renv_install_step_start("Installing", record$Package, verbose = FALSE)
+  renv_install_step_start("Installing", record, verbose = FALSE)
 
   before <- Sys.time()
   linker(cache, target)
@@ -545,7 +574,7 @@ renv_install_package_impl_prebuild <- function(record, path, quiet) {
   }
 
   verbose <- config$install.verbose()
-  renv_install_step_start("Building", record$Package, verbose = verbose)
+  renv_install_step_start("Building", record, verbose = verbose)
 
   before <- Sys.time()
   package <- record$Package
@@ -586,7 +615,7 @@ renv_install_package_impl <- function(record, quiet = TRUE) {
 
   # report start of installation to user
   verbose <- config$install.verbose()
-  renv_install_step_start("Installing", record$Package, verbose = verbose)
+  renv_install_step_start("Installing", record, verbose = verbose)
 
   # run user-defined hooks before, after install
   options <- renv_install_package_options(package)
@@ -682,6 +711,7 @@ renv_install_test <- function(package) {
   # intentionally throw an error in their .onAttach() hooks
   # https://github.com/rstudio/renv/issues/1611
   code <- expr({
+    .libPaths(!!.libPaths())
     options(warn = 1L)
     loadNamespace(!!package)
   })
@@ -754,7 +784,7 @@ renv_install_preflight_requirements <- function(records) {
   fmt <- "Package '%s' requires '%s', but '%s' will be installed"
   text <- sprintf(fmt, format(package), format(requires), format(actual))
   if (renv_verbose()) {
-    caution_bullets(
+    bulletin(
       "The following issues were discovered while preparing for installation:",
       text,
       "Installation of these packages may not succeed."
@@ -777,7 +807,7 @@ renv_install_postamble <- function(packages) {
   installed <- map_chr(packages, renv_package_version)
   loaded <- map_chr(packages, renv_namespace_version)
 
-  caution_bullets(
+  bulletin(
     c("", "The following loaded package(s) have been updated:"),
     packages[installed != loaded],
     "Restart your R session to use the new versions."
@@ -814,7 +844,7 @@ renv_install_preflight_permissions <- function(library) {
     postamble <- sprintf(fmt, info$effective_user %||% info$user)
 
     # print it
-    caution_bullets(
+    bulletin(
       preamble = preamble,
       values = library,
       postamble = postamble
@@ -847,12 +877,13 @@ renv_install_report <- function(records, library) {
   )
 }
 
-renv_install_step_start <- function(action, package, verbose = FALSE) {
+renv_install_step_start <- function(action, record, verbose = FALSE) {
 
+  pkgver <- paste(record[["Package"]], record[["Version"]])
   if (verbose)
-    return(writef("- %s %s ...", action, package))
+    return(writef("- %s %s ...", action, pkgver))
 
-  message <- sprintf("- %s %s ... ", action, package)
+  message <- sprintf("- %s %s ... ", action, pkgver)
   printf(format(message, width = the$install_step_width))
 
 }
