@@ -57,7 +57,7 @@ load <- function(project = NULL, quiet = FALSE, profile = NULL, ...) {
   base <- renv_load_base(sys.call(), envir = parent.frame())
   if (!is.null(base))
     return(invisible(base))
-  
+
   # eagerly load package namespaces which we rely on
   requireNamespace("compiler", quietly = TRUE)
 
@@ -162,12 +162,12 @@ renv_load_action <- function(project) {
     if (file.exists(file.path(parent, "renv")))
       return(parent)
   })
-  
+
   # the project has not yet been initialized; notify the user and ask
   # what they would like to do
   fmt <- "The project located at %s has not yet been initialized."
   header <- sprintf(fmt, renv_path_pretty(project))
-  
+
   # if we're running the autoloader in RStudio, we cannot ask
   # the user for input at this stage -- instead, just notify them
   # of the choices available
@@ -177,7 +177,7 @@ renv_load_action <- function(project) {
     caution(c(header, initmsg, loadmsg))
     return("none")
   }
-  
+
   # otherwise, prompt the user and provide them choices to proceed
   title <- paste("", header, "", "What would you like to do?", sep = "\n")
   choices <- c(
@@ -192,7 +192,7 @@ renv_load_action <- function(project) {
     choices <- c(choices, alt = msg)
   }
 
-  
+
   selection <- tryCatch(
     utils::select.list(choices, title = title, graphics = FALSE),
     interrupt = identity
@@ -620,7 +620,7 @@ renv_load_bioconductor <- function(project, bioconductor) {
     return()
 
   # if we don't have a valid Bioconductor version, bail
-  version <- bioconductor$Version
+  version <- bioconductor[["Version"]]
   if (is.null(version))
     return()
 
@@ -628,8 +628,10 @@ renv_load_bioconductor <- function(project, bioconductor) {
   renv_bioconductor_init()
 
   # validate version if necessary
-  validate <- getOption("renv.bioconductor.validate")
-  if (truthy(validate, default = TRUE))
+  # avoid doing this in non-interactive sessions, as it can rely on
+  # a web request to https://bioconductor.org/config.yaml, which can be slow
+  validate <- getOption("renv.bioconductor.validate", default = interactive())
+  if (truthy(validate, default = FALSE))
     renv_load_bioconductor_validate(project, version)
 
   # update the R repositories
@@ -642,29 +644,7 @@ renv_load_bioconductor <- function(project, bioconductor) {
 }
 
 renv_load_bioconductor_validate <- function(project, version) {
-
-  if (!identical(renv_bioconductor_manager(), "BiocManager"))
-    return()
-
-  BiocManager <- renv_scope_biocmanager()
-  if (!is.function(BiocManager$.version_validity))
-    return()
-
-  # check for valid version of Bioconductor
-  # https://github.com/rstudio/renv/issues/1148
-  status <- catch(BiocManager$.version_validity(version))
-  if (!is.character(status))
-    return()
-
-  fmt <- lines(
-    "This project is configured to use Bioconductor %1$s, which is not compatible with R %2$s.",
-    "Use 'renv::init(bioconductor = \"%1$s\")' to re-initialize this project with the appropriate Bioconductor release.",
-    if (renv_package_installed("BiocVersion"))
-      "Please uninstall the 'BiocVersion' package first, with `remove.packages(\"BiocVersion\")`."
-  )
-
-  warningf(fmt, version, getRversion())
-
+  renv_bioconductor_validate(version, prompt = FALSE)
 }
 
 renv_load_switch <- function(project) {
@@ -786,7 +766,7 @@ renv_load_check_description <- function(project) {
 
   values <- sprintf("[line %i is blank]", bad)
 
-  caution_bullets(
+  bulletin(
     sprintf("%s contains blank lines:", renv_path_pretty(descpath)),
     values,
     c(
