@@ -31,6 +31,7 @@ test_that("we can install a version of renv with a sha", {
 
   skip_on_cran()
   skip_on_ci()
+  skip_if_no_github_auth()
 
   renv_tests_scope()
 
@@ -58,7 +59,7 @@ test_that("bootstrap functions don't depend on non-bootstrap APIs", {
 
   # iterate over those functions and look for the called functions
   calls <- stack(mode = "character")
-  recurse(bodies, function(node, stack) {
+  recurse(bodies, function(node) {
     if (is.call(node) && is.symbol(node[[1L]]))
       calls$push(as.character(node[[1L]]))
   })
@@ -122,28 +123,34 @@ test_that("bootstrapping functions standalone", {
 })
 
 test_that("bootstrapping gives informative output when succesful", {
-  env <- environment()
 
+  scope <- environment()
   local_mocked_bindings(
+
     renv_bootstrap_download_impl = function(url, destfile) {
       file.create(destfile)
-      defer(unlink(destfile), env)
+      defer(unlink(destfile), scope = scope)
       0L
     },
+
     renv_bootstrap_install_impl = function(cmd, args, ...) {
       structure("", status = 0L)
     },
+
     renv_bootstrap_download_cran_latest_find = function(version) {
       if (package_version(version) < "1.0.0") {
         list(type = "binary", repos = "https://cran.rstudio.com")
       }
     },
+
     load = function(...) invisible()
+
   )
 
   renv_scope_options(renv.bootstrap.quiet = FALSE)
   library <- renv_scope_tempfile()
 
+  renv_tests_scope()
   expect_snapshot({
     bootstrap(version = "0.9.0", library = library)
     bootstrap(version = "1.0.0", library = library)
@@ -152,6 +159,7 @@ test_that("bootstrapping gives informative output when succesful", {
 })
 
 test_that("bootstrapping gives informative output when download fails", {
+
   local_mocked_bindings(
     renv_bootstrap_download_impl = function(...) {
       stop("test failure")
@@ -162,18 +170,21 @@ test_that("bootstrapping gives informative output when download fails", {
       }
     }
   )
+
   renv_scope_options(renv.bootstrap.quiet = FALSE)
   library <- renv_scope_tempfile()
 
+  renv_tests_scope()
   expect_snapshot(error = TRUE, {
     bootstrap(version = "0.9.0", library = library)
     bootstrap(version = "1.0.0", library = library)
     bootstrap(version = "1.0.0.1", library = library)
   })
+
 })
 
-
 test_that("bootstrapping gives informative output when install fails", {
+
   local_mocked_bindings(
     renv_bootstrap_download_impl = function(url, destfile) {
       file.create(destfile)
@@ -183,10 +194,14 @@ test_that("bootstrapping gives informative output when install fails", {
       structure("test failure", status = 123L)
     }
   )
+
   renv_scope_options(renv.bootstrap.quiet = FALSE)
   library <- renv_scope_tempfile()
 
-  expect_snapshot(bootstrap(version = "1.0.0.1", library = library), error = TRUE)
+  renv_tests_scope()
+  expect_snapshot(error = TRUE, {
+    bootstrap(version = "1.0.0.1", library = library)
+  })
 
 })
 
@@ -269,3 +284,47 @@ test_that("bootstrap version validation handles 'standard' remote types", {
   )
 
 })
+
+# repos override tests ----------------------------------------------------
+
+test_that("repos override supports unnamed repo", {
+  renv_tests_scope()
+  url <- "https://p3m.dev/cran/latest"
+  renv_scope_envvars(RENV_CONFIG_REPOS_OVERRIDE = url)
+  repos <- renv_bootstrap_repos()
+  expect_true(url %in% repos)
+})
+
+test_that("repos override can use 1 named repository", {
+  renv_tests_scope()
+  override <- "CRAN=https://p3m.dev/cran/latest"
+  renv_scope_envvars(RENV_CONFIG_REPOS_OVERRIDE = override)
+  repos <- renv_bootstrap_repos()
+  expect_equal(repos["CRAN"], c(CRAN = "https://p3m.dev/cran/latest"))
+})
+
+test_that("repos override can use 2+ named repositories", {
+  renv_tests_scope()
+  override <- "CRAN=https://p3m.dev/cran/latest;R_UNIV=https://posit-dev.r-universe.dev"
+  renv_scope_envvars(RENV_CONFIG_REPOS_OVERRIDE = override)
+  repos <- renv_bootstrap_repos()
+  expect_equal(repos["CRAN"], c(CRAN = "https://p3m.dev/cran/latest"))
+  expect_equal(repos["R_UNIV"], c(R_UNIV = "https://posit-dev.r-universe.dev"))
+  expect_equal(length(repos), 2L)
+})
+
+test_that("repos override can handle `=` in repo urls", {
+  renv_tests_scope()
+  override <- "R_UNIV=https://posit-dev.r-universe.dev/?example=query"
+  renv_scope_envvars(RENV_CONFIG_REPOS_OVERRIDE = override)
+  repos <- renv_bootstrap_repos()
+  expect_equal(repos["R_UNIV"], c(R_UNIV = "https://posit-dev.r-universe.dev/?example=query"))
+})
+
+test_that("repos override handle paths", {
+  renv_tests_scope()
+  override <- "CRAN=https://p3m.dev/cran/__linux__/noble/latest"
+  renv_scope_envvars(RENV_CONFIG_REPOS_OVERRIDE = override)
+  repos <- renv_bootstrap_repos()
+  expect_equal(repos["CRAN"], c(CRAN = "https://p3m.dev/cran/__linux__/noble/latest"))
+})
